/*
 * Copyright 2011 Chris de Vreeze
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.cdevreeze.springtx

import org.springframework.{ transaction => springtx }

/**
 * Scala wrapper for a Spring `TransactionTemplate`.
 * Trivial to use and understand for users of the Spring `TransactionTemplate` API, but idiomatic Scala.
 *
 * @author Chris de Vreeze
 */
final class TransactionTemplate(
  val wrappedObject: springtx.support.TransactionTemplate) extends TransactionOperations {

  require(wrappedObject ne null)

  def execute[T](action: springtx.TransactionStatus => T): T = {
    wrappedObject.execute(new springtx.support.TransactionCallback[T] {
      override def doInTransaction(status: springtx.TransactionStatus): T = action(status)
    })
  }

  def executeWithoutResult(action: springtx.TransactionStatus => Unit): Unit = {
    wrappedObject.execute(new springtx.support.TransactionCallbackWithoutResult {
      override def doInTransactionWithoutResult(status: springtx.TransactionStatus): Unit = action(status)
    })
  }
}
